@@ -16,7 +16,7 @@ use Log::Log4perl::Appender;
 
 use constant _INTERNAL_DEBUG => 1;
 
-our $VERSION = '1.01';
+our $VERSION = '1.03';
 
    # set this to '1' if you're using a wrapper
    # around Log::Log4perl
@@ -1338,7 +1338,7 @@ initialize Log::Log4perl seperately, try to consolidate your system
 to use a centralized Log4perl configuration file and use 
 Log4perl's I<categories> to separate your components.
 
-=head1 Custom Filters
+=head2 Custom Filters
 
 Log4perl allows the use of customized filters in its appenders
 to control the output of messages. These filters might grep for
@@ -1353,7 +1353,7 @@ on how to use them.
 =head2 Performance
 
 The performance of Log::Log4perl calls obviously depends on a lot of things.
-but to give you a general idea, here's some rough numbers:
+But to give you a general idea, here's some rough numbers:
 
 On a Pentium 4 Linux box at 2.4 GHz, you'll get through
 
@@ -1380,6 +1380,10 @@ document in the Log::Log4perl distribution.
 
 =head1 Cool Tricks
 
+Here's a collection of useful tricks for the advanced C<Log::Log4perl> user.
+For more, check the the FAQ, either in the distribution 
+(L<Log::Log4perl::FAQ>) or on http://log4perl.sourceforge.net.
+
 =head2 Shortcuts
 
 When getting an instance of a logger, instead of saying
@@ -2102,6 +2106,22 @@ can be retrieved by the C<appender_by_name()> class method. This comes
 in handy if you want to manipulate or query appender properties after
 the Log4perl configuration has been loaded via C<init()>.
 
+Note that internally, Log::Log4perl uses the C<Log::Log4perl::Appender> 
+wrapper class to control the real appenders (like 
+C<Log::Log4perl::Appender::File> or C<Log::Dispatch::FileRotate>). 
+The C<Log::Log4perl::Appender> class has an C<appender> attribute,
+pointing to the real appender.
+
+The reason for this is that external appenders like 
+C<Log::Dispatch::FileRotate> don't support all of Log::Log4perl's 
+appender control mechanisms (like appender thresholds).
+
+The previously mentioned method C<appender_by_name()> returns a
+referrence to the I<real> appender object. If you want access to the
+wrapper class (e.g. if you want to modify the appender's threshold),
+use the hash C<$Log::Log4perl::Logger::APPENDER_BY_NAME{...}> instead,
+which holds references all appender wrapper objects.
+
 =head2 Modify appender thresholds
 
 To conveniently adjust appender thresholds (e.g. because a script
@@ -2426,7 +2446,7 @@ http://www.perl.com/pub/a/2002/09/11/log4perl.html
 
 =item [2]
 
-Ceki Glc, "Short introduction to log4j",
+Ceki Gülcü, "Short introduction to log4j",
 http://jakarta.apache.org/log4j/docs/manual.html
 
 =item [3]
@@ -2465,6 +2485,7 @@ our
     Contributors:
     Hutton Davidson <Davidson.Hutton@ftid.com>
     Chris R. Donnelly <cdonnelly@digitalmotorworks.com>
+    Matisse Enzer
     James FitzGibbon <james.fitzgibbon@target.com>
     Dennis Gregorovic <dgregor@redhat.com>
     Paul Harrington <Paul-Harrington@deshaw.com>
